package	jp.co.sds_corp.util.daemon;

import java.io.Serializable;

import jp.co.sds_corp.util.config.IConfigSavable;
import jp.co.sds_corp.util.config.IConfigurable;

/**
* サービスの定義です。
*/
public interface IService extends IConfigurable, IConfigSavable, Serializable
{
	/** サービスの状態 */
	public enum Status {
		/** 状態：待ち */
		WAIT,
		/** 状態：実行中 */
		RUN,
		/** 状態：警告 */
		WARN,
		/** 状態：エラー */
		ERROR,
		/** 状態：不明 */
		UNKNOWN;
	}

	/**
	* サービス名を設定します。
	* @param	var		サービス名
	*/
	public void setName( String var );
	/**
	* サービス名を取得します。
	* @return	サービス名
	*/
	public String getName();

	/**
	* サービスを開始します。
	*/
	public void start();
	/**
	* サービスを終了します。
	*/
	public void stop();

	/**
	* サービスが割り込まれているかどうかを調べます。
	* @return	サービスが割り込まれている場合はtrue、そうでない場合はfalse
	*/
	public boolean isInterrupted();
	/**
	* サービスの割り込み状態を設定します。
	* @param	flg		サービスに割り込む場合はtrue、そうでない場合はfalse
	*/
	public void setInterrupt( boolean flg );
	/**
	* サービスが実行可能であるかを調べます。
	* @return   サービスが実行可能な場合はtrue、そうでない場合はfalse
	*/
	public boolean isValid();
	/**
	* サービス実行可能状態を設定します。
	* @param    var     サービスが実行可能な場合はtrue、そうでない場合はfalse
	*/
	public void setValid( boolean var );
	/**
	* サービスの状態を取得します。
	* @return	状態
	*/
	public Status getStatus();
	/**
	* サービスの状態を設定します。
	* @param	stat	状態
	*/
	public void setStatus( Status stat );
	/**
	* サービスの状態を文字列で取得します。
	* @return	状態
	*/
	public String getStatusString();

}
