package	jp.co.sds_corp.util.daemon.config;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.config.UnspecifiedPropertyException;

/**
* 設定ファイルを読み込む為のサポートツールを提供します。
*/
public final class ConfigUtility {
    /**
    * IConfigurationの"class"属性で指定されたクラスをインスタンス化します。
    */
    public static Object createInstance(IConfiguration config)
                throws UnspecifiedPropertyException,
                       ServiceInstantiationException {
        String className = config.getAttributes().get("class");
        try {
            return Class.forName(className).newInstance();
        } catch ( Throwable ex ) {
            CmnLog.warn( config, "[" + className + "] creation failed." );
            throw new ServiceInstantiationException(
                    "[" + className + "] creation failed.", ex );
        }
    }

    private ConfigUtility() {}
}
