package	jp.co.sds_corp.util.daemon.file;

import java.io.File;
import java.util.List;

import jp.co.sds_corp.util.config.IConfigSavable;
import jp.co.sds_corp.util.daemon.IService;

/**
* ファイル受信時に起動されるサービスの定義です。
*/
public interface IFileProcessor extends IService, IConfigSavable
{
	/**
	* 監視するディレクトリを指定します。
	* @param	dir		監視するディレクトリ
	*/
	public void setDirectory( File dir );
	/**
	* 監視するディレクトリを取得します。
	* @return	監視するディレクトリ
	*/
	public File getDirectory();

	/**
	* ファイル名フィルタを追加します。
	* @param	flt		ファイル名フィルタ
	*/
	public void addFilter( IFilenameFilter flt );
	/**
	* ファイル名フィルタを削除します。
	* @param	flt		ファイル名フィルタ
	*/
	public void removeFilter( IFilenameFilter flt );
	/**
	* ファイル名フィルタを取得します。
	* @return	ファイル名フィルタ
	*/
	public List<IFilenameFilter> listFilter();

	/**
	* 受信したファイルを処理します。
	* @param	file	受信したファイル
	*/
	public void start( File file ) throws Exception;

	/**
	* 処理すべきファイルがもうないことを通知します。
	*/
	public void endOfList() throws Exception;

}
