package	jp.co.sds_corp.util.daemon.remote;

import java.lang.reflect.Method;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.manager.DaemonManager;

/**
* デーモンマネージャを外部から制御するサーバクラスの基底クラスです。
*/
public abstract class AbstractServer implements IRemoteServer
{
	DaemonManager	manager;	// 処理対象のDaemonManager
	boolean	debug;	// debugフラグ
	String	type;	// サーバのタイプ

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		String sDebug = config.getAttributes().get( "debug", "false" );
		if ( sDebug != null && sDebug.equals( "true" )) {
			this.debug = true;
		}
	}

	/**
	* {@link Commander}のメソッドを呼び出します。
	* @param	cmd		Commander
	* @param	method	メソッド名
	* @param	cls		引数のクラス
	* @param	prm		引数のインスタンス
	*/
	protected Object command( Commander cmd,
								String method, Class<?>[] cls, Object[] prm )
		throws Exception
	{
		if ( isDebug()) {
			String log = "command:" + method + "(";
			if ( cls != null ) {
				for ( int i = 0; i < cls.length; i++ ) {
					if ( i > 0 ) {
						log += ",";
					}
					if ( prm.length >= (i+1) ) {
						log += prm[i];
					}
					log += "[" + cls[i].getName() + "]";
				}
			}
			log += ")";
			CmnLog.debug( this, log );
		}

		Method mtd = cmd.getClass().getMethod( method, cls );
		Object ret = mtd.invoke( cmd, prm );
		return ret;
	}

	/**
	* サーバのタイプを設定します。
	* @param	var		設定するデータ
	*/
	public void setType( String var ) {
		this.type = var;
	}
	/**
	* サーバのタイプを取得します。
	* @return	サーバのタイプ
	*/
	public String getType() {
		return type;
	}

	/**
	* 処理対象のDaemonManagerを設定します。
	* @param	var		設定するデータ
	*/
	public void setManager( DaemonManager var ) {
		this.manager = var;
	}
	/**
	* 処理対象のDaemonManagerを取得します。
	* @return	処理対象のDaemonManager
	*/
	public DaemonManager getManager() {
		return manager;
	}

	/**
	* debugフラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setDebug( boolean var ) {
		this.debug = var;
	}
	/**
	* debugフラグを取得します。
	* @return	debugフラグ
	*/
	public boolean isDebug() {
		return debug;
	}



}
