package	jp.co.sds_corp.util.daemon.remote.rmi;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.remote.IRemoteClient;
import jp.co.sds_corp.util.remote.ProcessController;

/**
* デーモンのRMI I/Fのクライアントです。
* DaemonManagerが使用するXMLファイルから、RMIのレジストリ情報を取得し
* DaemonManagerにコマンドを送信します。
*/
public class RMIClient implements IRemoteClient
{
	transient ProcessController controller = new ProcessController();
	String	host;	// ホスト名
	int	port;	// ポート番号
	String	name;	// RMI名
	String	user;	// ユーザ名
	String	password;	// パスワード

	/**
	* クライアントのタイプを返します。
	*/
	public String getType() {
		return "RMI";
	}

	/**
	* デーモンマネージャの RMIクライアントを初期化します。
	* @param    config  設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		setHost( config.get( "host" ));
		setPort( Integer.valueOf( config.get( "port" )).intValue());
		setName( config.get( "name" ));
		setUser( config.get( "user", null ));
		setPassword( config.get( "password", null ));
	}

	/**
	* RMIクライアントを終了します。
	*/
	public void exit() {
	}

	/**
	* 接続を開始します。
	*/
	public void connect() throws Exception {
		controller.connect();
	}
	/**
	* 接続を終了します。
	*/
	public void disconnect() throws Exception {
		controller.disconnect();
	}

	/**
	* 接続しているかを取得します。
	* @return	接続しているか
	*/
	public boolean isConnected() {
		return controller.isConnected();
	}

	/**
	* リモートのメソッドを呼び出します。
	* @param    cmd     メソッド名
	* @param    cls     パラメータのクラス
	* @param    prm     パラメータのオブジェクト
	*/
	public Object execRemote( String cmd, Class<?>[] cls, Object[] prm )
		throws Exception
	{
		return controller.execRemote( cmd, cls, prm );
	}
	/**
	* リモートのメソッドを呼び出します。
	* @param    cmd     メソッド名
	*/
	public Object execRemote( String cmd )
		throws Exception
	{
		return controller.execRemote( cmd );
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param    config  設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "type", "RMI" );
		config.addChild( "host", getHost() );
		config.addChild( "port", String.valueOf( getPort() ));
		config.addChild( "name", getName() );
	}

	/**
	* このクライアントの文字列表現を返します。
	* @return   クライアントの文字列表現
	*/
	public String toString() {
		String ret = "RMIClient [" + getHost() + ":" + getPort()
			+ "/" + getName() + "]";
		return ret;
	}

	/**
	* ホスト名を設定します。
	* @param	var		設定するデータ
	*/
	protected void setHost( String var ) {
		this.host = var;
		controller.setHost( var );
	}
	/**
	* ホスト名を取得します。
	* @return	ホスト名
	*/
	public String getHost() {
		return host;
	}

	/**
	* ポート番号を設定します。
	* @param	var		設定するデータ
	*/
	protected void setPort( int var ) {
		this.port = var;
		controller.setPort( var );
	}
	/**
	* ポート番号を取得します。
	* @return	ポート番号
	*/
	public int getPort() {
		return port;
	}

	/**
	* RMI名を設定します。
	* @param	var		設定するデータ
	*/
	protected void setName( String var ) {
		this.name = var;
		controller.setName( var );
	}
	/**
	* RMI名を取得します。
	* @return	RMI名
	*/
	public String getName() {
		return name;
	}

	/**
	* ユーザ名を設定します。
	* @param	var		設定するデータ
	*/
	protected void setUser( String var ) {
		this.user = var;
		controller.setUser( var );
	}
	/**
	* ユーザ名を取得します。
	* @return	ユーザ名
	*/
	public String getUser() {
		return user;
	}

	/**
	* パスワードを設定します。
	* @param	var		設定するデータ
	*/
	protected void setPassword( String var ) {
		this.password = var;
		controller.setPasswd( var );
	}
	/**
	* パスワードを取得します。
	* @return	パスワード
	*/
	public String getPassword() {
		return password;
	}


}

